.. ACTIONet documentation master file, created by
   sphinx-quickstart on Sun Jun  6 23:32:59 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ACTIONet's documentation!
====================================

.. toctree::
   :maxdepth: 5
   :caption: Contents:

   INTRODUCTION
   ACTIONet/modules.rst
   Tutorials/index.rst
   Tutorials/modules.rst
   FAQ
   CHANGELOG


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
